==> ann-0.3.tar.gz: ann-0.3/lib/ann_log_lazy.cpp <==
/***************************************************************************
                          ann_log_lazy.cpp  -  description
                             -------------------
    begin                : pi kwi 18 2003
    copyright            : (C) 2003 by Bartosz Lis
    email                : bartoszl@ics.p.lodz.pl
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <ann_log_lazy.h>
 
  //                     //
 // class ANN::Log_lazy //
//                     //

ANN::Log_lazy::~Log_lazy()
{
}

void
ANN::Log_lazy::prop_prepare(size_t epoch)
{
  active=!(epoch % epochs);
  ANN::Log_rec::prop_prepare(epoch);
}

void
ANN::Log_lazy::prop_update(size_t epoch)
{
  ANN::Log_rec::prop_update(epoch);
  active=false;
}

void
ANN::Log_lazy::prop_finish(size_t epoch)
{
  active=true;
  ANN::Log_rec::prop_finish(epoch);
}

void
ANN::Log_lazy::prop_finished(size_t epoch)
{
  ANN::Log_rec::prop_finished(epoch);
  active=false;
}

==> ann-0.4.tar.gz: ann-0.4/lib/ann_log_lazy.cpp <==
/***************************************************************************
                          ann_log_lazy.cpp  -  description
                             -------------------
    begin                : pi kwi 18 2003
    copyright            : (C) 2003 by Bartosz Lis
    email                : bartoszl@ics.p.lodz.pl
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <ann_log_lazy.h>
 
  //                     //
 // class ANN::Log_lazy //
//                     //

ANN::Log_lazy::~Log_lazy()
{
}

void
ANN::Log_lazy::prop_open(size_t epoch)
{
  active=!(epoch % epochs);
  ANN::Log_rec::prop_open(epoch);
}

void
ANN::Log_lazy::prop_close(size_t epoch)
{
  ANN::Log_rec::prop_close(epoch);
  active=false;
}

void
ANN::Log_lazy::prop_conclude(size_t epoch)
{
  active=true;
  ANN::Log_rec::prop_conclude(epoch);
}

void
ANN::Log_lazy::prop_concluded(size_t epoch)
{
  ANN::Log_rec::prop_concluded(epoch);
  active=false;
}
